## Summary
<!-- Brief description of the changes -->

## Changes
<!-- Detailed list of changes -->
-
-

## Type of Change
<!-- Check all that apply. These help generate release notes automatically. -->

- [ ] 🚨 Breaking change (incompatible API changes)
- [ ] 🎉 New feature (non-breaking new functionality)
- [ ] 🐛 Bug fix (non-breaking fix for an issue)
- [ ] 📚 Documentation update
- [ ] 🧪 Testing improvements
- [ ] 🏗️ Infrastructure/CI changes
- [ ] 🔧 Maintenance/refactoring
- [ ] 📦 Dependencies update
- [ ] 🔄 Other (please describe)

## Test Plan
<!-- Describe how you tested these changes -->

- [ ] Ran `make test-fast` - all tests pass
- [ ] Ran `make dev-check` - all quality checks pass
- [ ] Tested manually (describe below)

<!-- Manual testing details -->

## Related Issues
<!-- Link to related issues using "Closes #123" or "Relates to #456" -->

Closes #

## Checklist
<!-- Ensure all items are complete before requesting review -->

- [ ] Code follows project style guidelines
- [ ] Added/updated tests for changes
- [ ] Added/updated documentation
- [ ] All CI checks pass
- [ ] Appropriate labels applied for release notes
